@@ -1,22 +1,35 @@
-#
-# This file is part of Redis
-#
-# This software is Copyright (c) 2015 by Pedro Melo, Damien Krotkine.
-#
-# This is free software, licensed under:
-#
-#   The Artistic License 2.0 (GPL Compatible)
-#
 package Redis::List;
-$Redis::List::VERSION = '1.990_02';
-# ABSTRACT: tie Perl arrays to Redis lists
-# VERSION
-# AUTHORITY
 
 use strict;
 use warnings;
 use base qw/Redis Tie::Array/;
 
+=head1 NAME
+
+Redis::List - tie perl arrays into Redis lists
+
+=head1 SYNOPSYS
+
+    tie @my_list, 'Redis::List', 'list_name', @Redis_new_parameters;
+
+    $value = $my_list[$index];
+    $my_list[$index] = $value;
+
+    $count = @my_list;
+
+    push @my_list, 'values';
+    $value = pop @my_list;
+    unshift @my_list, 'values';
+    $value = shift @my_list;
+
+    ## NOTE: fourth parameter of splice is *NOT* supported for now
+    @other_list = splice(@my_list, 2, 3);
+
+    @my_list = ();
+
+
+=cut
+
 
 sub TIEARRAY {
   my ($class, $list, @rest) = @_;
@@ -92,61 +105,4 @@ sub EXTEND {
 
 sub DESTROY { $_[0]->quit }
 
-1;    ## End of Redis::List
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Redis::List - tie Perl arrays to Redis lists
-
-=head1 VERSION
-
-version 1.990_02
-
-=head1 SYNOPSYS
-
-    tie @my_list, 'Redis::List', 'list_name', @Redis_new_parameters;
-
-    $value = $my_list[$index];
-    $my_list[$index] = $value;
-
-    $count = @my_list;
-
-    push @my_list, 'values';
-    $value = pop @my_list;
-    unshift @my_list, 'values';
-    $value = shift @my_list;
-
-    ## NOTE: fourth parameter of splice is *NOT* supported for now
-    @other_list = splice(@my_list, 2, 3);
-
-    @my_list = ();
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Pedro Melo <melo@cpan.org>
-
-=item *
-
-Damien Krotkine <dams@cpan.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2015 by Pedro Melo, Damien Krotkine.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
+1;
